summaryrefslogtreecommitdiffstats
path: root/views/widget/widget.h
diff options
context:
space:
mode:
authorglen@chromium.org <glen@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-29 21:36:27 +0000
committerglen@chromium.org <glen@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-29 21:36:27 +0000
commitc3b0173e79820fbb5252d873fc14ea70c1132bcc (patch)
treefb62e177d227247afc74b72c2c35fa08291ccef4 /views/widget/widget.h
parentf2880572b01b32c7e9ccbb0a289fd207a8d3bbf5 (diff)
downloadchromium_src-c3b0173e79820fbb5252d873fc14ea70c1132bcc.zip
chromium_src-c3b0173e79820fbb5252d873fc14ea70c1132bcc.tar.gz
chromium_src-c3b0173e79820fbb5252d873fc14ea70c1132bcc.tar.bz2
Revert Revision 17224
BUG=none TEST=non Review URL: http://codereview.chromium.org/115951 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@17245 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'views/widget/widget.h')
-rw-r--r--views/widget/widget.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/views/widget/widget.h b/views/widget/widget.h
index 14a61a0..efa16c5 100644
--- a/views/widget/widget.h
+++ b/views/widget/widget.h
@@ -104,10 +104,10 @@ class Widget {
// Get the theme provider.
virtual ThemeProvider* GetThemeProvider() const { return NULL; }
- // Get the default theme provider; this is necessary for when a widget has
- // no profile (and ThemeProvider) associated with it. The default theme
- // provider provides a default set of bitmaps that such widgets can use.
- virtual ThemeProvider* GetDefaultThemeProvider() { return NULL; }
+ // Get the dialog theme provider; this is necessary for when a dialog has
+ // no profile (and ThemeProvider) associated with it. The dialog theme
+ // provider provides a default set of bitmaps that such dialogs can use.
+ virtual ThemeProvider* GetDialogThemeProvider() { return NULL; }
};
} // namespace views